Module backend

Module backend 

Swappable text shaping backends.

Defines the ShapeBackend trait so consumers can choose between the default swash-based backend and the optional rustybuzz backend without changing any other part of the pipeline.

Structs

SwashShaperBackend
Swash-based shaper — delegates to crate::SwashShaper.

Traits

ShapeBackend
Trait for swappable text shaping backends.